==> python-easy-math-0.1.0.tar.gz: python-easy-math-0.1.0/README.md <==
# python-easy-math

<table>
    <tr>
        <td>License</td>
        <td><img src='https://img.shields.io/pypi/l/python-easy-math.svg'></td>
        <td>Version</td>
        <td><img src='https://img.shields.io/pypi/v/python-easy-math.svg'></td>
    </tr>
    <tr>
        <td>Travis CI</td>
        <td><img src='https://travis-ci.org/svpernova09/python-easy-math.svg?branch=master'></td>
        <td>Coverage</td>
        <td><img src='https://codecov.io/gh/svpernova09/python-easy-math/branch/master/graph/badge.svg'></td>
    </tr>
    <tr>
        <td>Wheel</td>
        <td><img src='https://img.shields.io/pypi/wheel/python-easy-math.svg'></td>
        <td>Implementation</td>
        <td><img src='https://img.shields.io/pypi/implementation/python-easy-math.svg'></td>
    </tr>
    <tr>
        <td>Status</td>
        <td><img src='https://img.shields.io/pypi/status/python-easy-math.svg'></td>
        <td>Downloads</td>
        <td><img src='https://img.shields.io/pypi/dm/python-easy-math.svg'></td>
    </tr>
    <tr>
        <td>Supported versions</td>
        <td><img src='https://img.shields.io/pypi/pyversions/python-easy-math.svg'></td>
    </tr>
</table>

## A simple library to do math for you
 
Python Easy Math provides two classes containing two methods each. The Addition file provides the `add()` method which takes two parameters and returns the sum. The Subtraction file provides a single `subtract()` class that takes two parameters and will return the difference of the supplied parameters.

==> python-easy-math-1.0.0.tar.gz: python-easy-math-1.0.0/README.md <==
# python-easy-math

<table>
    <tr>
        <td>License</td>
        <td><img src='https://img.shields.io/pypi/l/python-easy-math.svg'></td>
        <td>Version</td>
        <td><img src='https://img.shields.io/pypi/v/python-easy-math.svg'></td>
    </tr>
    <tr>
        <td>Travis CI</td>
        <td><img src='https://travis-ci.org/svpernova09/python-easy-math.svg?branch=master'></td>
        <td>Coverage</td>
        <td><img src='https://codecov.io/gh/svpernova09/python-easy-math/branch/master/graph/badge.svg'></td>
    </tr>
    <tr>
        <td>Wheel</td>
        <td><img src='https://img.shields.io/pypi/wheel/python-easy-math.svg'></td>
        <td>Implementation</td>
        <td><img src='https://img.shields.io/pypi/implementation/python-easy-math.svg'></td>
    </tr>
    <tr>
        <td>Status</td>
        <td><img src='https://img.shields.io/pypi/status/python-easy-math.svg'></td>
        <td>Downloads</td>
        <td><img src='https://img.shields.io/pypi/dm/python-easy-math.svg'></td>
    </tr>
    <tr>
        <td>Supported versions</td>
        <td><img src='https://img.shields.io/pypi/pyversions/python-easy-math.svg'></td>
    </tr>
</table>

## A simple library to do math for you
 
Python Easy Math provides `addition.py` and `subtraction.py`. The Addition file provides the `add()` method which takes two parameters and returns the sum. The Subtraction file provides a single `subtract()` class that takes two parameters and will return the difference of the supplied parameters.
